Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(869)

Unified Diff: content/browser/download/download_create_info.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/download/download_create_info.h
diff --git a/content/browser/download/download_create_info.h b/content/browser/download/download_create_info.h
index ead25417dbc82e81ff8ef51281fd79340dd1edb5..d5dc3eba4e4d5988b01ce26e3b4c4eb5a6254314 100644
--- a/content/browser/download/download_create_info.h
+++ b/content/browser/download/download_create_info.h
@@ -28,7 +28,7 @@ namespace content {
// want to pass |DownloadItem|s between threads.
struct CONTENT_EXPORT DownloadCreateInfo {
DownloadCreateInfo(const base::Time& start_time,
- const net::BoundNetLog& bound_net_log,
+ const net::NetLogWithSource& net_log,
std::unique_ptr<DownloadSaveInfo> save_info);
DownloadCreateInfo();
~DownloadCreateInfo();
@@ -81,9 +81,9 @@ struct CONTENT_EXPORT DownloadCreateInfo {
// The handle to the URLRequest sourcing this download.
std::unique_ptr<DownloadRequestHandleInterface> request_handle;
// The request's |BoundNetLog|, for "source_dependency" linking with the
// download item's.
- const net::BoundNetLog request_bound_net_log;
+ const net::NetLogWithSource request_net_log;
// ---------------------------------------------------------------------------
// The remaining fields are Entity-body properties. These are only set if
@@ -81,9 +81,9 @@ struct CONTENT_EXPORT DownloadCreateInfo {
// The handle to the URLRequest sourcing this download.
std::unique_ptr<DownloadRequestHandleInterface> request_handle;
- // The request's |BoundNetLog|, for "source_dependency" linking with the
+ // The request's |NetLogWithSource|, for "source_dependency" linking with the
// download item's.

Powered by Google App Engine
This is Rietveld 408576698